@@ -16,9 +16,9 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#ifndef __PDF_DOCUMENT_H__
-#define __PDF_DOCUMENT_H__
+#pragma once
 
+#include "ev-macros.h"
 #include "ev-document.h"
 
 G_BEGIN_DECLS
@@ -32,9 +32,7 @@ typedef struct _PdfDocumentClass PdfDocumentClass;
 
 GType                 pdf_document_get_type   (void) G_GNUC_CONST;
 
-G_MODULE_EXPORT GType register_evince_backend (GTypeModule *module);
-
+EV_PUBLIC
+GType                 register_evince_backend (GTypeModule *module);
 
 G_END_DECLS
-
-#endif /* __PDF_DOCUMENT_H__ */
