@@ -28,6 +28,7 @@
 #include "ev-document-forms.h"
 #include "ev-document-images.h"
 #include "ev-document-annotations.h"
+#include "ev-document-media.h"
 #include "ev-document-text.h"
 #include "ev-page-cache.h"
 
@@ -48,6 +49,7 @@ typedef struct _EvPageCacheData {
 	EvMappingList     *image_mapping;
 	EvMappingList     *form_field_mapping;
 	EvMappingList     *annot_mapping;
+        EvMappingList     *media_mapping;
 	cairo_region_t    *text_mapping;
 	EvRectangle       *text_layout;
 	guint              text_layout_length;
@@ -80,7 +82,8 @@ struct _EvPageCacheClass {
 	EV_PAGE_DATA_INCLUDE_TEXT_MAPPING | \
 	EV_PAGE_DATA_INCLUDE_IMAGES       | \
 	EV_PAGE_DATA_INCLUDE_FORMS        | \
-	EV_PAGE_DATA_INCLUDE_ANNOTS)
+	EV_PAGE_DATA_INCLUDE_ANNOTS       | \
+        EV_PAGE_DATA_INCLUDE_MEDIA)
 
 #define PRE_CACHE_SIZE 1
 
@@ -94,55 +97,23 @@ G_DEFINE_TYPE (EvPageCache, ev_page_cache, G_TYPE_OBJECT)
 static void
 ev_page_cache_data_free (EvPageCacheData *data)
 {
-	if (data->job) {
-		g_object_unref (data->job);
-		data->job = NULL;
-	}
+	g_clear_object (&data->job);
 
-	if (data->link_mapping) {
-		ev_mapping_list_unref (data->link_mapping);
-		data->link_mapping = NULL;
-	}
+	g_clear_pointer (&data->link_mapping, ev_mapping_list_unref);
+	g_clear_pointer (&data->image_mapping, ev_mapping_list_unref);
+	g_clear_pointer (&data->form_field_mapping, ev_mapping_list_unref);
+	g_clear_pointer (&data->annot_mapping, ev_mapping_list_unref);
+	g_clear_pointer (&data->media_mapping, ev_mapping_list_unref);
+	g_clear_pointer (&data->text_mapping, cairo_region_destroy);
 
-	if (data->image_mapping) {
-		ev_mapping_list_unref (data->image_mapping);
-		data->image_mapping = NULL;
-	}
+	g_clear_pointer (&data->text_layout, g_free);
+	data->text_layout_length = 0;
 
-	if (data->form_field_mapping) {
-		ev_mapping_list_unref (data->form_field_mapping);
-		data->form_field_mapping = NULL;
-	}
-
-	if (data->annot_mapping) {
-		ev_mapping_list_unref (data->annot_mapping);
-		data->annot_mapping = NULL;
-	}
-
-	if (data->text_mapping) {
-		cairo_region_destroy (data->text_mapping);
-		data->text_mapping = NULL;
-	}
-
-	if (data->text_layout) {
-		g_free (data->text_layout);
-		data->text_layout = NULL;
-		data->text_layout_length = 0;
-	}
-
-	if (data->text) {
-		g_free (data->text);
-		data->text = NULL;
-	}
-
-	if (data->text_attrs) {
-		pango_attr_list_unref (data->text_attrs);
-		data->text_attrs = NULL;
-	}
+	g_clear_pointer (&data->text, g_free);
+	g_clear_pointer (&data->text_attrs, pango_attr_list_unref);
 
         if (data->text_log_attrs) {
-                g_free (data->text_log_attrs);
-                data->text_log_attrs = NULL;
+		g_clear_pointer (&data->text_log_attrs, g_free);
                 data->text_log_attrs_length = 0;
         }
 }
@@ -170,15 +141,11 @@ ev_page_cache_finalize (GObject *object)
 			ev_page_cache_data_free (data);
 		}
 
-		g_free (cache->page_list);
-		cache->page_list = NULL;
+		g_clear_pointer (&cache->page_list, g_free);
 		cache->n_pages = 0;
 	}
 
-	if (cache->document) {
-		g_object_unref (cache->document);
-		cache->document = NULL;
-	}
+	g_clear_object (&cache->document);
 
 	G_OBJECT_CLASS (ev_page_cache_parent_class)->finalize (object);
 }
@@ -239,6 +206,12 @@ ev_page_cache_get_flags_for_data (EvPageCache     *cache,
 			flags | EV_PAGE_DATA_INCLUDE_ANNOTS;
 	}
 
+	if (cache->flags & EV_PAGE_DATA_INCLUDE_MEDIA) {
+		flags = (data->media_mapping) ?
+			flags & ~EV_PAGE_DATA_INCLUDE_MEDIA :
+			flags | EV_PAGE_DATA_INCLUDE_MEDIA;
+	}
+
 	if (cache->flags & EV_PAGE_DATA_INCLUDE_TEXT_MAPPING) {
 		flags = (data->text_mapping) ?
 			flags & ~EV_PAGE_DATA_INCLUDE_TEXT_MAPPING :
@@ -305,6 +278,8 @@ job_page_data_finished_cb (EvJob       *job,
 		data->form_field_mapping = job_data->form_field_mapping;
 	if (job_data->flags & EV_PAGE_DATA_INCLUDE_ANNOTS)
 		data->annot_mapping = job_data->annot_mapping;
+        if (job_data->flags & EV_PAGE_DATA_INCLUDE_MEDIA)
+                data->media_mapping = job_data->media_mapping;
 	if (job_data->flags & EV_PAGE_DATA_INCLUDE_TEXT_MAPPING)
 		data->text_mapping = job_data->text_mapping;
 	if (job_data->flags & EV_PAGE_DATA_INCLUDE_TEXT_LAYOUT) {
@@ -323,8 +298,7 @@ job_page_data_finished_cb (EvJob       *job,
 	data->done = TRUE;
 	data->dirty = FALSE;
 
-	g_object_unref (data->job);
-	data->job = NULL;
+	g_clear_object (&data->job);
 
         g_signal_emit (cache, ev_page_cache_signals[PAGE_CACHED], 0, job_data->page);
 }
@@ -333,8 +307,7 @@ static void
 job_page_data_cancelled_cb (EvJob           *job,
 			    EvPageCacheData *data)
 {
-	g_object_unref (data->job);
-	data->job = NULL;
+	g_clear_object (&data->job);
 }
 
 static void
@@ -442,6 +415,9 @@ ev_page_cache_mark_dirty (EvPageCache       *cache,
 	if (flags & EV_PAGE_DATA_INCLUDE_ANNOTS)
                 g_clear_pointer (&data->annot_mapping, ev_mapping_list_unref);
 
+        if (flags & EV_PAGE_DATA_INCLUDE_MEDIA)
+                g_clear_pointer (&data->media_mapping, ev_mapping_list_unref);
+
 	if (flags & EV_PAGE_DATA_INCLUDE_TEXT_MAPPING)
                 g_clear_pointer (&data->text_mapping, cairo_region_destroy);
 
@@ -553,6 +529,28 @@ ev_page_cache_get_annot_mapping (EvPageCache *cache,
 	return data->annot_mapping;
 }
 
+EvMappingList *
+ev_page_cache_get_media_mapping (EvPageCache *cache,
+				 gint         page)
+{
+	EvPageCacheData *data;
+
+	g_return_val_if_fail (EV_IS_PAGE_CACHE (cache), NULL);
+	g_return_val_if_fail (page >= 0 && page < cache->n_pages, NULL);
+
+	if (!(cache->flags & EV_PAGE_DATA_INCLUDE_MEDIA))
+		return NULL;
+
+	data = &cache->page_list[page];
+	if (data->done)
+		return data->media_mapping;
+
+	if (data->job)
+		return EV_JOB_PAGE_DATA (data->job)->media_mapping;
+
+	return data->media_mapping;
+}
+
 cairo_region_t *
 ev_page_cache_get_text_mapping (EvPageCache *cache,
 				gint         page)
